@@ -200,6 +200,14 @@ fn checked_jacobi(&self, k: &Self) -> Option<i8>{
      return None
  }
  
+ fn smooth(&self) -> Self{
+     let k = self.factor();
+     k[k.len()-2]
+ }
+ 
+ fn is_smooth(&self, b: &Self) -> bool{
+     &self.smooth() <= b
+ }
 
 }
 
@@ -317,4 +325,13 @@ impl NumberTheory for i8{
  }
  
  
+ fn smooth(&self) -> Self{
+     let k = self.factor();
+     k[k.len()-2]
+ }
+ 
+ fn is_smooth(&self, b: &Self) -> bool{
+     self.smooth() <= b.abs()
+ }
+ 
 }
